@@ -11,30 +11,31 @@ from libtmux import test  # NOQA
 # Get the project root dir, which is the parent dir of this
 cwd = Path(__file__).parent
 project_root = cwd.parent
+project_src = project_root / "src"
 
-sys.path.insert(0, str(project_root))
+sys.path.insert(0, str(project_src))
 sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: Dict[str, str] = {}
-with open(project_root / "libtmux" / "__about__.py") as fp:
+with open(project_src / "libtmux" / "__about__.py") as fp:
     exec(fp.read(), about)
 
 extensions = [
     "sphinx.ext.autodoc",
-    "autoapi.extension",
     "sphinx.ext.intersphinx",
     "sphinx_autodoc_typehints",
     "sphinx.ext.todo",
     "sphinx.ext.linkcode",
     "sphinx.ext.napoleon",
-    "sphinx_issues",
     "sphinx_click.ext",  # sphinx-click
     "sphinx_inline_tabs",
     "sphinx_copybutton",
     "sphinxext.opengraph",
     "sphinxext.rediraffe",
     "myst_parser",
+    "linkify_issues",
+    "sphinx_toctree_autodoc_fix",
 ]
 
 myst_enable_extensions = [
@@ -44,8 +45,6 @@ myst_enable_extensions = [
     "strikethrough",
 ]
 
-issues_github_path = about["__github__"].replace("https://github.com/", "")
-
 templates_path = ["_templates"]
 
 source_suffix = {".rst": "restructuredtext", ".md": "markdown"}
@@ -96,16 +95,12 @@ html_sidebars = {
     ]
 }
 
+# linkify_issues
+issue_url_tpl = f'{about["__github__"]}/issues/{{issue_id}}'
+
 # sphinx.ext.autodoc
 autoclass_content = "both"
 autodoc_member_order = "bysource"
-autosummary_generate = True
-
-# sphinx-autoapi
-autoapi_type = "python"
-autoapi_dirs = [project_root / "libtmux"]
-autoapi_generate_api_docs = False  # when fales, use directives
-suppress_warnings = ["autoapi.python_import_resolution", "autoapi.not_readable"]
 
 # sphinx-copybutton
 copybutton_prompt_text = (
@@ -158,7 +153,10 @@ texinfo_documents = [
     )
 ]
 
-intersphinx_mapping = {"http://docs.python.org/": None}
+intersphinx_mapping = {
+    "": ("https://docs.python.org/", None),
+    "pytest": ("https://docs.pytest.org/en/stable/", None),
+}
 
 
 def linkcode_resolve(
